@@ -30,9 +30,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '',
- 'CONFIGURE_CFLAGS_NODIST': '-O3 -pipe -march=znver2 -mtune=znver3 '
-                            '-frecord-gcc-switches -fdiagnostics-color=never '
-                            '-fwrapv -std=c11 -Wextra -Wno-unused-parameter '
+ 'CONFIGURE_CFLAGS_NODIST': '-march=x86-64 -O2 -pipe -fwrapv -std=c11 -Wextra '
+                            '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
@@ -46,8 +45,9 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--host=x86_64-pc-linux-gnu' '--mandir=/usr/share/man' "
                 "'--infodir=/usr/share/info' '--datadir=/usr/share' "
                 "'--sysconfdir=/etc' '--localstatedir=/var/lib' "
-                "'--docdir=/usr/share/doc/python-3.11.8' "
-                "'--htmldir=/usr/share/doc/python-3.11.8/html' "
+                "'--datarootdir=/usr/share' "
+                "'--docdir=/usr/share/doc/python-3.11.11_p2' "
+                "'--htmldir=/usr/share/doc/python-3.11.11_p2/html' "
                 "'--libdir=/usr/lib64' 'ac_cv_header_stropts_h=no' "
                 "'--enable-shared' '--without-static-libpython' "
                 "'--enable-ipv6' '--infodir=/usr/share/info' "
@@ -55,7 +55,8 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-dbmliborder=gdbm' '--with-libc=' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
                 "'--without-lto' '--with-system-expat' '--with-system-ffi' "
-                "'--with-platlibdir=lib' '--with-pkg-config=yes' "
+                "'--with-system-libmpdec' '--with-platlibdir=lib' "
+                "'--with-pkg-config=yes' "
                 "'--with-wheel-pkg-dir=/usr/lib/python/ensurepip' "
                 "'--without-assertions' '--disable-optimizations' "
                 "'--with-readline=readline' '--without-valgrind' "
@@ -66,17 +67,16 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.11',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.11.8/work/Python-3.11.8/coverage.info',
+ 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.11.11_p2/work/Python-3.11.11/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.11.8/work/Python-3.11.8/lcov-report',
+ 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.11.11_p2/work/Python-3.11.11/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.11 LCOV report [commit $(shell '
                             ')]"',
  'CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
  'CXX': 'x86_64-pc-linux-gnu-g++',
- 'DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 -DANSI=1 '
-                   '-DHAVE_UINT128_T=1',
- 'DECIMAL_LDFLAGS': '-lm Modules/_decimal/libmpdec/libmpdec.a',
+ 'DECIMAL_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1',
+ 'DECIMAL_LDFLAGS': '-lmpdec',
  'DEEPFREEZE_C': 'Python/deepfreeze/deepfreeze.c',
  'DEEPFREEZE_DEPS': './Tools/scripts/deepfreeze.py _bootstrap_python '
                     './Programs/_freeze_module.py \\',
@@ -614,15 +614,14 @@ build_time_vars = {'ABIFLAGS': '',
                    '/usr/include/python3.11',
  'INCLUDEDIR': '/usr/include',
  'INCLUDEPY': '/usr/include/python3.11',
- 'INSTALL': '/var/tmp/portage/._portage_reinstall_.o0ixbqx6/bin/ebuild-helpers/xattr/install '
-            '-c',
- 'INSTALL_DATA': '/var/tmp/portage/._portage_reinstall_.o0ixbqx6/bin/ebuild-helpers/xattr/install '
-                 '-c -m 644',
- 'INSTALL_PROGRAM': '/var/tmp/portage/._portage_reinstall_.o0ixbqx6/bin/ebuild-helpers/xattr/install '
+ 'INSTALL': '/usr/lib/portage/python3.12/ebuild-helpers/xattr/install -c',
+ 'INSTALL_DATA': '/usr/lib/portage/python3.12/ebuild-helpers/xattr/install -c '
+                 '-m 644',
+ 'INSTALL_PROGRAM': '/usr/lib/portage/python3.12/ebuild-helpers/xattr/install '
                     '-c',
- 'INSTALL_SCRIPT': '/var/tmp/portage/._portage_reinstall_.o0ixbqx6/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SCRIPT': '/usr/lib/portage/python3.12/ebuild-helpers/xattr/install '
                    '-c',
- 'INSTALL_SHARED': '/var/tmp/portage/._portage_reinstall_.o0ixbqx6/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SHARED': '/usr/lib/portage/python3.12/ebuild-helpers/xattr/install '
                    '-c -m 755',
  'INSTSONAME': 'libpython3.11.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
@@ -638,11 +637,10 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDEST': '/usr/lib/python3.11',
  'LIBDIR': '/usr/lib64',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-Wsign-compare -DNDEBUG -O3 -pipe -march=znver2 '
-                    '-mtune=znver3 -frecord-gcc-switches '
-                    '-fdiagnostics-color=never -fwrapv -std=c11 -Wextra '
-                    '-Wno-unused-parameter -Wno-missing-field-initializers '
-                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
+ 'LIBEXPAT_CFLAGS': '-Wsign-compare -DNDEBUG -march=x86-64 -O2 -pipe -fwrapv '
+                    '-std=c11 -Wextra -Wno-unused-parameter '
+                    '-Wno-missing-field-initializers -Wstrict-prototypes '
+                    '-Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                     '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
@@ -650,10 +648,8 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBFFI_INCLUDEDIR': '/usr/lib64/libffi/include',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
- 'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 -DANSI=1 '
-                    '-DHAVE_UINT128_T=1 -Wsign-compare -DNDEBUG -O3 -pipe '
-                    '-march=znver2 -mtune=znver3 -frecord-gcc-switches '
-                    '-fdiagnostics-color=never -fwrapv -std=c11 -Wextra '
+ 'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 -Wsign-compare '
+                    '-DNDEBUG -march=x86-64 -O2 -pipe -fwrapv -std=c11 -Wextra '
                     '-Wno-unused-parameter -Wno-missing-field-initializers '
                     '-Wstrict-prototypes -Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
@@ -807,11 +803,9 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__DATETIME_LDFLAGS': '-lm',
  'MODULE__DATETIME_STATE': 'yes',
  'MODULE__DBM_STATE': 'yes',
- 'MODULE__DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 '
-                           '-DANSI=1 -DHAVE_UINT128_T=1',
- 'MODULE__DECIMAL_DEPS': './Modules/_decimal/docstrings.h \\ '
-                         'Modules/_decimal/libmpdec/libmpdec.a',
- 'MODULE__DECIMAL_LDFLAGS': '-lm Modules/_decimal/libmpdec/libmpdec.a',
+ 'MODULE__DECIMAL_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1',
+ 'MODULE__DECIMAL_DEPS': './Modules/_decimal/docstrings.h',
+ 'MODULE__DECIMAL_LDFLAGS': '-lmpdec',
  'MODULE__DECIMAL_STATE': 'yes',
  'MODULE__ELEMENTTREE_CFLAGS': '',
  'MODULE__ELEMENTTREE_DEPS': './Modules/pyexpat.c',
@@ -893,6 +887,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__TESTINTERNALCAPI_STATE': 'yes',
  'MODULE__TESTMULTIPHASE_STATE': 'yes',
  'MODULE__THREAD_LDFLAGS': '',
+ 'MODULE__TKINTER_CFLAGS': '-Wno-strict-prototypes -DWITH_APPINIT=1',
+ 'MODULE__TKINTER_LDFLAGS': '-ltk8.6 -ltkstub8.6 -ltcl8.6 -ltclstub8.6',
  'MODULE__TKINTER_STATE': 'disabled',
  'MODULE__TRACEMALLOC_LDFLAGS': '',
  'MODULE__TYPING_STATE': 'yes',
@@ -948,10 +944,8 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O3 -pipe -march=znver2 '
-                             '-mtune=znver3 -frecord-gcc-switches '
-                             '-fdiagnostics-color=never -fwrapv -std=c11 '
-                             '-Wextra -Wno-unused-parameter '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -DNDEBUG -march=x86-64 -O2 -pipe '
+                             '-fwrapv -std=c11 -Wextra -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
@@ -959,19 +953,17 @@ build_time_vars = {'ABIFLAGS': '',
                              '-I./Include -I/usr/include/ncursesw -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wsign-compare -DNDEBUG',
- 'PY_CFLAGS_NODIST': '-O3 -pipe -march=znver2 -mtune=znver3 '
-                     '-frecord-gcc-switches -fdiagnostics-color=never -fwrapv '
-                     '-std=c11 -Wextra -Wno-unused-parameter '
-                     '-Wno-missing-field-initializers -Wstrict-prototypes '
+ 'PY_CFLAGS_NODIST': '-march=x86-64 -O2 -pipe -fwrapv -std=c11 -Wextra '
+                     '-Wno-unused-parameter -Wno-missing-field-initializers '
+                     '-Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wsign-compare -DNDEBUG -O3 -pipe -march=znver2 '
-                   '-mtune=znver3 -frecord-gcc-switches '
-                   '-fdiagnostics-color=never -fwrapv -std=c11 -Wextra '
-                   '-Wno-unused-parameter -Wno-missing-field-initializers '
-                   '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
+ 'PY_CORE_CFLAGS': '-Wsign-compare -DNDEBUG -march=x86-64 -O2 -pipe -fwrapv '
+                   '-std=c11 -Wextra -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers -Wstrict-prototypes '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
+                   '-I./Include/internal -I. -I./Include '
                    '-I/usr/include/ncursesw -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
@@ -984,11 +976,9 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O3 -pipe -march=znver2 '
-                        '-mtune=znver3 -frecord-gcc-switches '
-                        '-fdiagnostics-color=never -fwrapv -std=c11 -Wextra '
-                        '-Wno-unused-parameter -Wno-missing-field-initializers '
-                        '-Wstrict-prototypes '
+ 'PY_STDMODULE_CFLAGS': '-Wsign-compare -DNDEBUG -march=x86-64 -O2 -pipe '
+                        '-fwrapv -std=c11 -Wextra -Wno-unused-parameter '
+                        '-Wno-missing-field-initializers -Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
                         '-I./Include -I/usr/include/ncursesw -fPIC',
@@ -1003,7 +993,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'x86_64-pc-linux-gnu-readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.8/work/Python-3.11.8',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.11_p2/work/Python-3.11.11',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -1047,10 +1037,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.8/work/Python-3.11.8 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.11_p2/work/Python-3.11.11 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.8/work/Python-3.11.8 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.11_p2/work/Python-3.11.11 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -1068,7 +1058,7 @@ build_time_vars = {'ABIFLAGS': '',
  'WASM_ASSETS_DIR': './usr',
  'WASM_STDLIB': './usr/lib/python3.11/os.py',
  'WHEEL_PKG_DIR': '/usr/lib/python/ensurepip',
- 'WINDOW_HAS_FLAGS': 1,
+ 'WINDOW_HAS_FLAGS': 0,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 0,
@@ -1081,8 +1071,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.11.8/work/Python-3.11.8',
- 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.11.8/work/Python-3.11.8',
+ 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.11.11_p2/work/Python-3.11.11',
+ 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.11.11_p2/work/Python-3.11.11',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
